import bb.cascades 1.3
import QTimer 1.0
import "../Squircle"

Container {
    id: templateContainer
    property bool blockEnabled: true
    property string blockName
    property alias blockText: label.text
    property bool notAvailable: false
    property bool isTrigger: true
    signal clicked()
    signal longPressed()
    signal helpClicked()

    onBlockEnabledChanged: {
        if (blockEnabled) {
            vibrationAnimation.stop()
            timer.stop()
            blockImage.rotationZ = 0
        }
        else {
            vibrationAnimation.play()
            timer.start()
        }
    }
    
    layoutProperties: StackLayoutProperties { spaceQuota: 1 }
    background: mainPage.backgroundSecondColor
    horizontalAlignment: HorizontalAlignment.Fill
    verticalAlignment: VerticalAlignment.Fill
    leftPadding: ui.du(0.2)
    rightPadding: leftPadding
    topPadding: leftPadding
    bottomPadding: leftPadding
    minHeight: rootBlockContainer.height
    maxHeight: minHeight
    minWidth: rootBlockContainer.width
    maxWidth: minWidth
    
    gestureHandlers: [
        TapHandler {
            onTapped: { templateContainer.clicked(); console.log("Clicked"); }
        },
        LongPressHandler {
            onLongPressed: { templateContainer.longPressed(); console.log("Long Pressed"); }
        }
    ]
    
    attachedObjects:  [
        QTimer {
            id: timer
            interval: 3000
            onTimeout: vibrationAnimation.play()
        }
    ]
    
    onCreationCompleted: {
        if (!templateContainer.blockEnabled) {
            vibrationAnimation.play()
            timer.start()
        }
    }

    Container {
        layout: DockLayout {}
        background: mainPage.blockBackgroundColor
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        minHeight: rootBlockContainer.height
        maxHeight: minHeight
        minWidth: rootBlockContainer.width
        maxWidth: minWidth

        Container {
            layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Center
            opacity: blockEnabled ? 1 : 0.4
            leftPadding: ui.du(1)
            rightPadding: leftPadding
            Container {
                layout: DockLayout {}
                verticalAlignment: VerticalAlignment.Center
                ImageView {
                    visible: false
                    imageSource: "asset:///images/circle.png"
                    minHeight: rootBlockContainer.height * 0.75
                    maxHeight: minHeight
                    minWidth: minHeight
                    maxWidth: minHeight
                    scalingMethod: ScalingMethod.AspectFit
                    verticalAlignment: VerticalAlignment.Center
                }
                ImageView {
                    id: blockImage
                    property int angle: 10
                    property int oneVibeDuration: 50
                    
                    imageSource: "asset:///images/" + blockName + ".png"
                    minHeight: rootBlockContainer.height * 0.75
                    maxHeight: minHeight
                    minWidth: minHeight
                    maxWidth: minHeight
                    scalingMethod: ScalingMethod.AspectFit
                    verticalAlignment: VerticalAlignment.Center
                    animations: [
                        SequentialAnimation {
                            id: vibrationAnimation
                            animations: [
                                RotateTransition { toAngleZ: blockImage.angle; duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: (0 - blockImage.angle); duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: blockImage.angle; duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: (0 - blockImage.angle); duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: blockImage.angle; duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: (0 - blockImage.angle); duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: blockImage.angle; duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: (0 - blockImage.angle); duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: blockImage.angle; duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: (0 - blockImage.angle); duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: blockImage.angle; duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: (0 - blockImage.angle); duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: blockImage.angle; duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: (0 - blockImage.angle); duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: blockImage.angle; duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: (0 - blockImage.angle); duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: blockImage.angle; duration: blockImage.oneVibeDuration},
                                RotateTransition { toAngleZ: 0; duration: blockImage.oneVibeDuration; }
                            ]
                        }
                    ]
                }
            }
            Label {
                id: label
                verticalAlignment: VerticalAlignment.Center
                multiline: true
            }
        }
    }
}
