import bb.cascades 1.3
import bb.system 1.2

Container {
    layout: DockLayout {}
    leftPadding: ui.du(1)
    rightPadding: leftPadding
    topPadding: leftPadding
    bottomPadding: leftPadding
    
    Container {
        id: rootBlockContainer
        property int height: (_app.deviceInfo.deviceHeight - parent.topPadding - parent.bottomPadding) / rootBlockContainer.count()
        property int width: (_app.deviceInfo.deviceWidth - parent.leftPadding - parent.rightPadding) / 2
        Container {
            // First line
            layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
            horizontalAlignment: HorizontalAlignment.Fill
            minHeight: rootBlockContainer.height
            minWidth: rootBlockContainer.width * 2
            onCreationCompleted: { _bluetoothHandler.bluetoothWatchedNameChanged.connect(onBluetoothWatchedNameChanged) }
            function onBluetoothWatchedNameChanged(name) { 
                if (name != "") {
                    _settings.setValue("bluetoothConnectionLostWatch", true)
                    bluetoothBlock.blockEnabled = true
                }
            }
            BlockTemplate { 
                blockEnabled: _app.mainProtectionEnabled
//                blockName: settingsSheet.debugModeOn ? "Squircle" : "Shield" 
                blockName: "ProtectMe_inAppIcon2"
//                blockText: _app.mainProtectionEnabled ? qsTr("Protected") + Retranslate.onLanguageChanged : qsTr("Not Protected") + Retranslate.onLanguageChanged
                blockText: qsTr("Main Protection") + Retranslate.onLanguageChanged
                onClicked: { 
                    _app.setMainProtectionEnabled(!_app.mainProtectionEnabled)
                    if (!_app.mainProtectionEnabled) {
                        toast.body = qsTr("Main protection turned OFF, your device is not protected.") + Retranslate.onLanguageChanged
                        toast.button.label = qsTr("OK") + Retranslate.onLanguageChanged
                        toast.show()
                    }
                }
                onLongPressed: {
                    toast.body = qsTr("This is your main protection. Your device will not be protected if you set it to OFF. No triggers will be able to lock the phone, no matter if those triggers are enabled or not.\n\nRecommended status: Enabled.") + Retranslate.onLanguageChanged
                    toast.button.label = qsTr("OK") + Retranslate.onLanguageChanged
                    toast.show()
                }
            }
            BlockTemplate { 
                id: bluetoothBlock
                blockName: "Bluetooth"
                blockText: (_bluetoothHandler.bluetoothWatchedName == "") ? qsTr("Bluetooth not set") : _bluetoothHandler.bluetoothWatchedName
                blockEnabled: (_bluetoothHandler.bluetoothWatchedName == "") ? false : _settings.value("bluetoothConnectionLostWatch", true)
                onClicked: {
                    if (_bluetoothHandler.bluetoothWatchedName == "") {
                        _bluetoothHandler.showBluetoothDialog()
                    }
                    else {
                        _settings.setValue("bluetoothConnectionLostWatch", !_settings.value("bluetoothConnectionLostWatch", true))
                        blockEnabled = _settings.value("bluetoothConnectionLostWatch", true)
                        if (blockEnabled) _bluetoothHandler.showBluetoothDialog()
                    }
                }
                onLongPressed: {
                    toast.body = qsTr("With Bluetooth Trigger, your device will lock if a chosen Bluetooth device loose connection with your phone. This is meant for wearables, like Pebble and FitBit.\nTo choose a wearable to monitor, disable and enable this option.\n\nRecommended status: Enabled if used with a wearable.") + Retranslate.onLanguageChanged
                    toast.button.label = qsTr("OK") + Retranslate.onLanguageChanged
                    toast.show()
                }
                onCreationCompleted: { _bluetoothHandler.noBluetoothDeviceFound.connect(onNoBluetoothDeviceFound) }
                function onNoBluetoothDeviceFound() {
                    _settings.setValue("bluetoothConnectionLostWatch", false)
                    blockEnabled = false
                    toast.body = qsTr("No Bluetooth Device found") + Retranslate.onLanguageChanged
                    toast.button.label = qsTr("OK") + Retranslate.onLanguageChanged
                    toast.show()
                }
            }
        }
        
        Container {
            // Second line
            layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
            horizontalAlignment: HorizontalAlignment.Fill
            minHeight: rootBlockContainer.height
            minWidth: rootBlockContainer.width
            BlockTemplate { 
                blockName: "Pim"
                blockText: qsTr("Remote Message Trigger") + Retranslate.onLanguageChanged
                blockEnabled: _settings.value("pimWatch", true)
                onClicked: {
                    _settings.setValue("pimWatch", !_settings.value("pimWatch", true))
                    blockEnabled = _settings.value("pimWatch", true)
                }
                onLongPressed: {
                    toast.body = qsTr("With Remote Message Trigger, you can send a predefined message (keyword) to your phone to remotely lock the device. Just borrow someone else's phone and send to your lost device an email, SMS or PIN message with your keyword as subject.\n\nRecommended status: Enabled.") + Retranslate.onLanguageChanged
                    toast.button.label = qsTr("OK") + Retranslate.onLanguageChanged
                    toast.show()
                }
            }
            BlockTemplate { 
                blockName: "AirplaneMode"
                blockText: qsTr("Airplane Mode ON Trigger") + Retranslate.onLanguageChanged
                blockEnabled: _settings.value("airplaneModeWatch", true)
                onClicked: {
                    _settings.setValue("airplaneModeWatch", !_settings.value("airplaneModeWatch", true))
                    blockEnabled = _settings.value("airplaneModeWatch", true)
                }
                onLongPressed: {
                    toast.body = qsTr("With Airplane Mode ON Trigger, your device will lock if your phone goes in Airplane Mode.\n\nProtectMe won't be able to send your GPS coordinates if Airplane Mode is ON, but your device will be password protected.\n\nRecommended status: Enabled.") + Retranslate.onLanguageChanged
                    toast.button.label = qsTr("OK") + Retranslate.onLanguageChanged
                    toast.show()
                }
            }
        }
        
        Container {
            // Third line
            layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
            horizontalAlignment: HorizontalAlignment.Fill
            minHeight: rootBlockContainer.height
            minWidth: rootBlockContainer.width
            BlockTemplate { 
                blockName: "CellularService"
                blockText: qsTr("Cellular Service OFF Trigger") + Retranslate.onLanguageChanged
                blockEnabled: _settings.value("cellularWatch", true)
                onClicked: {
                    _settings.setValue("cellularWatch", !_settings.value("cellularWatch", true))
                    blockEnabled = _settings.value("cellularWatch", true)
                }
                onLongPressed: {
                    toast.body = qsTr("With Cellular Service OFF Trigger, your device will lock if Cellular Service (phone, SMS and data) is turned OFF.\n\nProtectMe won't be able to send your GPS coordinates if Cellular Service is OFF, but your device will be password protected.\n\nRecommended status: Enabled.") + Retranslate.onLanguageChanged
                    toast.button.label = qsTr("OK") + Retranslate.onLanguageChanged
                    toast.show()
                }
            }
            BlockTemplate { 
                blockName: "DataServiceMode"
                blockText: qsTr("Data Service OFF Trigger") + Retranslate.onLanguageChanged
                blockEnabled: _settings.value("dataServiceModeWatch", true)
                onClicked: {
                    _settings.setValue("dataServiceModeWatch", !_settings.value("dataServiceModeWatch", true))
                    blockEnabled = _settings.value("dataServiceModeWatch", true)
                }
                onLongPressed: {
                    toast.body = qsTr("With Data Service OFF Trigger, your device will lock if Data Service (Edge, 3G, 4G mobile data) is turned OFF.\n\nProtectMe won't be able to send your GPS coordinates if Data Service is OFF, but your device will be password protected.\n\nRecommended status: Enabled.") + Retranslate.onLanguageChanged
                    toast.button.label = qsTr("OK") + Retranslate.onLanguageChanged
                    toast.show()
                }
            }
        }
        
        Container {
            // Third line
            layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
            horizontalAlignment: HorizontalAlignment.Fill
            minHeight: rootBlockContainer.height
            minWidth: rootBlockContainer.width
            BlockTemplate { 
                blockName: "Wifi"
                blockText: qsTr("Wi-Fi OFF Trigger") + Retranslate.onLanguageChanged
                blockEnabled: _settings.value("wifiWatch", false)
                onClicked: {
                    _settings.setValue("wifiWatch", !_settings.value("wifiWatch", false))
                    blockEnabled = _settings.value("wifiWatch", false)
                }
                onLongPressed: {
                    toast.body = qsTr("With Wi-Fi OFF Trigger, your device will lock if Wi-Fi is turned OFF.\n\nRecommended status: Disabled if you have access to mobile data, otherwise Enabled.") + Retranslate.onLanguageChanged
                    toast.button.label = qsTr("OK") + Retranslate.onLanguageChanged
                    toast.show()
                }
            }
            BlockTemplate { 
                blockName: "GPS"
                blockText: qsTr("Location Service OFF Trigger") + Retranslate.onLanguageChanged
                blockEnabled: _settings.value("gpsWatch", true)
                onClicked: {
                    _settings.setValue("gpsWatch", !_settings.value("gpsWatch", true))
                    blockEnabled = _settings.value("gpsWatch", true)
                }
                onLongPressed: {
                    toast.body = qsTr("With Location Service OFF Trigger, your device will lock if GPS is turned OFF.\n\nRecommended status: Enabled.") + Retranslate.onLanguageChanged
                    toast.button.label = qsTr("OK") + Retranslate.onLanguageChanged
                    toast.show()
                }
            }
        }

        Container {
            // Forth line
            layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
            horizontalAlignment: HorizontalAlignment.Fill
            minHeight: rootBlockContainer.height
            minWidth: rootBlockContainer.width
            BlockTemplate { 
                blockName: "Shutdown"
                blockText: qsTr("Shutdown Attempt Trigger") + Retranslate.onLanguageChanged
                blockEnabled: _settings.value("powerButtonLongPressWatch", true)
                onClicked: {
                    _settings.setValue("powerButtonLongPressWatch", !_settings.value("powerButtonLongPressWatch", true))
                    blockEnabled = _settings.value("powerButtonLongPressWatch", true)
                }
                onLongPressed: {
                    toast.body = qsTr("With Shutdown Attempt Trigger, your device will lock if POWER button is long-pressed to shutdown the device, no matter if they do shutdown the phone or hit Cancel.\n\nRecommended status: Enabled.") + Retranslate.onLanguageChanged
                    toast.button.label = qsTr("OK") + Retranslate.onLanguageChanged
                    toast.show()
                }
            }
            BlockTemplate { 
                blockName: "SoftReset"
                blockText: qsTr("Soft Reset Attempt Trigger") + Retranslate.onLanguageChanged
                blockEnabled: _settings.value("softResetButtonsLongPressWatch", true)
                onClicked: {
                    _settings.setValue("softResetButtonsLongPressWatch", !_settings.value("softResetButtonsLongPressWatch", true))
                    blockEnabled = _settings.value("softResetButtonsLongPressWatch", true)
                }
                onLongPressed: {
                    toast.body = qsTr("With Soft Reset Attempt Trigger, your device will lock if VOLUME UP and VOLUME DOWN buttons are long-pressed to perform a soft reset.\n\nRecommended status: Enabled.") + Retranslate.onLanguageChanged
                    toast.button.label = qsTr("OK") + Retranslate.onLanguageChanged
                    toast.show()
                }
            }
        }

        Container {
            // Fifth line
            layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
            horizontalAlignment: HorizontalAlignment.Fill
            minHeight: rootBlockContainer.height
            minWidth: rootBlockContainer.width
            BlockTemplate { 
                blockName: "Settings"
                blockText: "Settings"
                isTrigger: false
                onClicked: { settingsSheet.open() }
                onLongPressed: { settingsSheet.open() }
            }
            BlockTemplate { 
                blockName: "PayPal"
                blockText: "Support this app"
                isTrigger: false
                onClicked: { donateToast.show() }
                onLongPressed: { donateToast.show() }
                attachedObjects: [
                    SystemToast {
                        id: donateToast
                        body: "This app is supported by your donation, you'll be redirected to my PayPal donation account."
                        button.label: "Ok"
                        onFinished: {
                            donateInvocation.query.invokeActionId = "bb.action.OPEN"
                            donateInvocation.query.invokeTargetId = "sys.browser"
                            donateInvocation.query.uri = "https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=SPVU4HNBUJBH2"
                            donateInvocation.query.updateQuery()
                        }
                    },
                    Invocation {
                        id: donateInvocation
                        onArmed: { trigger(query.invokeActionId) }
                    }
                ]
            }
        }
    }
}
