import bb.cascades 1.3
import bb.system 1.2
import "../Actions"
import "../CustomElements/Settings"
import "../Squircle"

Sheet {
    id: settingsSheet
    
    property bool debugModeOn: _settings.value("sendToConsoleDebug", false)
    property bool showHiddenOptionsModeOn: _settings.value("showHiddenOptions", false)
    
    onOpened: { Application.setMenuEnabled(false) }
    onClosed: { Application.setMenuEnabled(true) }
    
    Page {
        titleBar: TitleBar {
            title: qsTr("Settings") + Retranslate.onLanguageChanged
            acceptAction: ActionItem {
                title: qsTr("Ok") + Retranslate.onLanguageChanged
                onTriggered: {
                    settingsSheet.close()
                }
            }
        }
        
        actions: [
            ChangePasswordAction {},
            LostPasswordAction {}
        ]
        
        ScrollView {
            Container {
                id: mainContainer
                
                background: mainPage.blockBackgroundColor
                leftPadding: ui.du(3)
                rightPadding: leftPadding
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill
                
                property double numberOfDoubleTaps: 0
                property double numberOfLongPresses: 0
                
                gestureHandlers: [
                    LongPressHandler {
                        onLongPressed: {
                            mainContainer.numberOfLongPresses++
                            if (mainContainer.numberOfLongPresses == 2) {
                                mainContainer.numberOfLongPresses = 0
                                _settings.setValue("showHiddenOptions", !_settings.value("showHiddenOptions", false))
                                settingsSheet.showHiddenOptionsModeOn = _settings.value("showHiddenOptions", false)
                                systemToast.body = qsTr("Hidden options shown: ") + Retranslate.onLanguageChanged + (_settings.value("sendToConsoleDebug", false) ? (qsTr("ON") + Retranslate.onLanguageChanged) : (qsTr("OFF") + Retranslate.onLanguageChanged))
                                systemToast.show()
                            }
                        }                        
                    },
                    DoubleTapHandler {
                        onDoubleTapped: {
                            mainContainer.numberOfDoubleTaps++
                            if (mainContainer.numberOfDoubleTaps == 5) {
                                mainContainer.numberOfDoubleTaps = 0
                                _settings.setValue("sendToConsoleDebug", !_settings.value("sendToConsoleDebug", false))
//                            _app.setEnvironment("SEND_TO_CONSOLEDEBUG", _settings.value("sendToConsoleDebug", false).toString());
                                settingsSheet.debugModeOn = _settings.value("sendToConsoleDebug", false)
                                systemToast.body = qsTr("ConsoleDebug mode set to ") + Retranslate.onLanguageChanged + (_settings.value("sendToConsoleDebug", false) ? (qsTr("ON") + Retranslate.onLanguageChanged) : (qsTr("OFF") + Retranslate.onLanguageChanged))
                                systemToast.show()
                            }
                        }
                        attachedObjects: [
                            SystemToast {
                                id: systemToast
                            }
                        ]
                    }
                ]
                
                ScrollView {
                    Container {
                        topPadding: ui.du(5)
                        bottomPadding: topPadding
                        Container {
                            layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
                            Button {
                                text: "Shutdown"
                                visible: debugModeOn
                                onClicked: {
                                    _app.sendToHL("SHUTDOWN")
                                    Application.quit()
                                }
                            }
                            Button {
                                text: "GPS Refresh"
                                visible: debugModeOn
                                onClicked: {
                                    _app.sendToHL("GPS_REFRESH")
                                }
                            }
                            Button {
                                text: "Simulate entering a Safe Zone"
                                visible: debugModeOn
                                onClicked: {
                                    _app.sendToHL("GEOREGIONENTER")
                                }
                            }
                        }
                        
                        KeywordContainer {}
                        CustomDivider {}
                        DefaultEmail {}
                        CustomDivider {}
                        LockScreenMessage {}
                        CustomDivider {}
                        VibeAlerts {}
                        CustomDivider {}
                        SoundAlerts {}
                        CustomDivider {}
                        SafeZone {}
                        CustomDivider {}
//                        SendCrashReport {}
//                        CustomDivider {}
                        ShowEnhancedBluetoothResult { visible: settingsSheet.showHiddenOptionsModeOn }
                    }
                }
            }
        }
    }
}