import bb.cascades 1.3
import bb.system 1.2

Sheet {
    id: tutorialSheet
    onOpened: {
        listView.scrollToItem([0], ScrollAnimation.Smooth)
        listView.sheetOpened = true
        mainPage.tutorialOpened = true
        if (aboutSheet.opened)
            aboutSheet.close()
    }
    onClosed: {
        listView.sheetOpened = false
        mainPage.tutorialOpened = false
    }
    
    attachedObjects: [
        SystemToast {
            id: systemToast
        }
    ]
    
    Page {
        id: tutorialPage
        titleBar: TitleBar {
            id: titleBar
            title: qsTr("Tutorial") + Retranslate.onLanguageChanged
            acceptAction: ActionItem {
                title: tutorialPage.pageShown == (listView.dataModel.childCount([]) - 1) ? qsTr("Done") : qsTr("Next")
                onTriggered: {
                    //listView.dataModel.childCount([])                    
                    if (tutorialPage.pageShown == (listView.dataModel.childCount([])) - 1) {
                        if (_settings.value("showFirstTimeTutorial", true))
                            _settings.setValue("showFirstTimeTutorial", false)
                            
                        tutorialSheet.close()
                    }
                    else 
                        listView.scrollToItem([tutorialPage.pageShown + 1], ScrollAnimation.Smooth)
                }
            }
            dismissAction: ActionItem {
                title: qsTr("Cancel") + Retranslate.onLanguageChanged
                onTriggered: {
                    tutorialSheet.close()
                }
            }
        }
                
        property int pageShown
        
        Container {
            id: tutorialContainer
            layout: DockLayout {}
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            attachedObjects: LayoutUpdateHandler { id: luhContainer }
            topPadding: luhContainer.layoutFrame.height * 0.05
            bottomPadding: topPadding
            leftPadding: luhContainer.layoutFrame.width * 0.05
            rightPadding: leftPadding
            background: mainPage.blockBackgroundColor
            ListView {
                id: listView
                
                property int deviceWidth: luhContainer.layoutFrame.width * 0.90
                property int deviceHeight: luhContainer.layoutFrame.height * 0.90
                property int itemLeftPadding: luhContainer.layoutFrame.width * 0.05
                property int itemTopPadding: luhContainer.layoutFrame.height * 0.05
                property bool sheetOpened
                property variant background: tutorialContainer.background

                scrollRole: mainPage.tutorialOpened ? ScrollRole.Main : ScrollRole.None
                dataModel: XmlDataModel { source: qsTr("asset:///Tutorial/tutorialModel.xml") + Retranslate.onLanguageChanged }
                layout: StackListLayout { orientation: LayoutOrientation.LeftToRight }
                flickMode: FlickMode.SingleItem
                
                function updatePageShown(page) {
                    tutorialPage.pageShown = page
                }
                
                listItemComponents: [
                    ListItemComponent {
                        type: "item"
                        Container {
                            id: itemContainer
                            layout: DockLayout {}
                            preferredWidth: itemContainer.ListItem.view.deviceWidth
                            preferredHeight: itemContainer.ListItem.view.deviceHeight
                            attachedObjects: LayoutUpdateHandler {
                                id: luhPosition
                                onLayoutFrameChanged: {
                                    if (luhPosition.layoutFrame.x >= - itemContainer.preferredWidth / 2 && luhPosition.layoutFrame.x <= itemContainer.preferredWidth / 2) {
                                        itemContainer.ListItem.view.updatePageShown(ListItemData.page)
                                        if (ListItemData.image != "") fadeTransition.play()
                                    } 
                                }
                            }
                            Container {
                                layout: DockLayout {}
                                horizontalAlignment: HorizontalAlignment.Fill
                                verticalAlignment: VerticalAlignment.Fill
                                ImageView {
                                    imageSource: ListItemData.image
                                    horizontalAlignment: HorizontalAlignment.Center
                                    verticalAlignment: VerticalAlignment.Top
                                    maxHeight: itemContainer.ListItem.view.deviceHeight * 0.75
                                    maxWidth: maxWidth
                                    scalingMethod: ScalingMethod.AspectFit
                                }
                                Container {
                                    horizontalAlignment: HorizontalAlignment.Fill
                                    verticalAlignment: (ListItemData.image != "") ? VerticalAlignment.Bottom : VerticalAlignment.Center
                                    opacity: (ListItemData.image != "") ? 0 : 0.9
                                    background: itemContainer.ListItem.view.background
                                    animations: [
                                        FadeTransition {
                                            id: fadeTransition
                                            fromOpacity: 0
                                            toOpacity: 0.9
                                            duration: 1500
//                                            easingCurve: StockCurve.CircularInOut
                                        }
                                    ]
                                    ScrollView {
                                        maxHeight: itemContainer.ListItem.view.deviceHeight
                                        horizontalAlignment: HorizontalAlignment.Center
                                        Container {
                                            Label {
                                                text: ListItemData.description
                                                multiline: true
                                                textStyle.textAlign: TextAlign.Justify
                                                textStyle.fontSize: FontSize.XLarge
                                                horizontalAlignment: HorizontalAlignment.Center
                                                textStyle.color: Color.White
                                            }
                                            Button {
                                                text: qsTr("Open Security Settings") + Retranslate.onLanguageChanged
                                                horizontalAlignment: HorizontalAlignment.Center
                                                onClicked: { _app.invokeSettings() }
                                                visible: (ListItemData.buttonVisible == "true")
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                ]    
            }
        }
    }
}
