/*
 * Copyright (c) 2013-2015 BlackBerry Limited.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import bb.cascades 1.3
import bb.system 1.2
import bb.platform 1.3
import "ActiveFrame"
import "CustomElements"
import "Sheets"
import "Tutorial"

Page {
    id: mainPage
    property variant backgroundColor: Color.create("#FFFF933C")
    property variant blockBackgroundColor: Color.create("#FF4B4F5E")
    property variant backgroundSecondColor: Color.Black
    property variant foregroundColor: Color.create("#FFB65D28")
    property variant textColor: Color.create("#FFFF933C")
    property variant secondTextColor: Color.White
//    property variant secondTextColor: Color.create("#FFB65D28")
    property bool tutorialOpened: false
    
    onTutorialOpenedChanged: {
        if (!tutorialOpened) {
            toast.body = qsTr("Click on icons to enable or disable.\nLong-press on icons to get help.") + Retranslate.onLanguageChanged
            toast.button.label = qsTr("OK") + Retranslate.onLanguageChanged
            toast.show()
        }
    }

    Menu.definition: MenuDefinition {
        settingsAction: SettingsActionItem {
            imageSource: "asset:///images/Settings.png"
            onTriggered: { settingsSheet.open() }
        }
        actions: [
            ActionItem {
                title: qsTr("About")
                ActionBar.placement: ActionBarPlacement.OnBar
                imageSource: "asset:///images/About.png"
                onTriggered: { aboutSheet.open() }
            }
        ]      
    }
    
    onCreationCompleted: {
        Application.setCover(activeFrame)
//        Application.setMenuEnabled(false)
        
        Application.fullscreen.connect(onFullscreen)

        if (!_settings.value("defaultEmailWarningShownOnce", false)) {
            Application.thumbnail.connect(onThumbnail)
        }

        if (_settings.value("password", "") == "") {
            setPasswordPrompt.show()
        }
        else {
            blocksContainer.visible = false
            if (settingsSheet.debugModeOn) {
                blocksContainer.opacity = 0
                blocksContainer.visible = true
                blocksContainerFadeAnimation.play()
            }
            else {
                accessAppPrompt.show()
            }
        }
    }
        
    function onFullscreen() {
        if (!_settings.value("password", "") == "") {
            if (!settingsSheet.debugModeOn) { 
                blocksContainer.visible = false
                accessAppPrompt.show() 
            }
        }
    }

    function onThumbnail() {
        console.log("onThumbnail()")
        if (_settings.value("defaultEmailWarningShownOnce", false)) {
            return
        }
        
        if ((_settings.value("defaultSenderEmailAccount", -1) == -1) || (_settings.value("defaultReceiverEmailAccount", "") == "")) {
            notificationDialog.title = qsTr("Settings not completed") + Retranslate.onLanguageChanged
            notificationDialog.body = qsTr("You haven't set a default email account for sending GPS coordinates, you will not receive email alerts when your phone locks. To ensure maximum security, we are redirecting you to Settings page where you can enter default email account.\n\n(This warning will never show up again)") + Retranslate.onLanguageChanged
            notificationDialog.show()
            console.log("notificationDialog.show()")
        }
    }
        
    attachedObjects: [
        AboutSheet { id: aboutSheet },
        ActiveFrame { id: activeFrame },
        LostPasswordSheet { id: lostPasswordSheet },
        SettingsSheet { id: settingsSheet },
        TutorialSheet { id: tutorialSheet },
        NotificationDialog { 
            id: notificationDialog
            buttons: [ SystemUiButton { label: qsTr("OK") + Retranslate.onLanguageChanged } ] 
            onFinished: {
                _settings.setValue("defaultEmailWarningShownOnce", true)
                settingsSheet.open()
            }
        },
        SystemPrompt {
            id: setPasswordPrompt
            title: qsTr("Enter new password") + Retranslate.onLanguageChanged
            body: qsTr("Please enter a new password. (4 characters minimum)") + Retranslate.onLanguageChanged
            inputField.inputMode: SystemUiInputMode.Password
            onFinished: {
                if (inputFieldTextEntry().length >= 4) {
                    _settings.setValue("password", inputFieldTextEntry())
                    toast.body = qsTr("Password set successfully") + Retranslate.onLanguageChanged
                    toast.show()

                    if ((_settings.value("lostPasswordQuestion", "") == "") || (_settings.value("lostPasswordAnswer", "") == ""))
                        lostPasswordSheet.open()                    
                }
                else {
                    setPasswordPrompt.show()
                }
            }
        },
        SystemToast {
            id: toast
            onBodyChanged: { 
                if (body == "") 
                    allFadeInAnimation.play() 
                else 
                    allFadeOutAnimation.play() 
            }
            onFinished: {
                body = ""
                button.label = ""
            }
        },
        SystemPrompt {
            id: accessAppPrompt
            title: qsTr("Enter password") + Retranslate.onLanguageChanged
            body: qsTr("To access this app, you need to enter the password.") + Retranslate.onLanguageChanged
            inputField.inputMode: SystemUiInputMode.Password
            onFinished: {
                if ((buttonSelection() == cancelButton) && ((_settings.value("lostPasswordQuestion", "") != "") && (_settings.value("lostPasswordAnswer", "") != ""))) {
                    lostPasswordPrompt.show()
                }
                else {
                    if (inputFieldTextEntry() != _settings.value("password", "CellNinja")) {
                        wrongPasswordToast.show()
                    }
                    else {
                        blocksContainer.opacity = 0
                        blocksContainer.visible = true
                        blocksContainerFadeAnimation.play()
                    }
                }
            }
        },
        SystemPrompt {
            id: lostPasswordPrompt
            title: qsTr("Lost Password Question") + Retranslate.onLanguageChanged
            body: _settings.value("lostPasswordQuestion", "")
            inputField.inputMode: SystemUiInputMode.Password
            onFinished: {
                if (inputFieldTextEntry() == _settings.value("lostPasswordAnswer", "")) {
                    blocksContainer.opacity = 0
                    blocksContainer.visible = true
                    blocksContainerFadeAnimation.play()
                }
                else {
                    wrongPasswordToast.show()
                }
            }
        },
        SystemToast {
            id: wrongPasswordToast
            body: qsTr("Wrong password.") + Retranslate.onLanguageChanged
            button.label: qsTr("OK") + Retranslate.onLanguageChanged
            onFinished: {
                accessAppPrompt.show()
            }
        },
        TextStyleDefinition {
            id: headingStyle
            fontSize: FontSize.PointValue
            fontSizeValue: 20
            color: mainPage.textColor
        },
        TextStyleDefinition {
            id: lockScreenStyle
            fontSize: FontSize.PointValue
            fontSizeValue: 14
            color: mainPage.textColor
        }
    ]
    
    Container {
        layout: DockLayout {}
        horizontalAlignment: HorizontalAlignment.Fill
        verticalAlignment: VerticalAlignment.Fill
        background: mainPage.backgroundColor
        
        animations: [
            FadeTransition {
                id: allFadeOutAnimation
                fromOpacity: 1
                toOpacity: 0.1
                duration: 2000
            },
            FadeTransition {
                id: allFadeInAnimation
                fromOpacity: 0.1
                toOpacity: 1
                duration: 600
            }
        ]
        
        BlocksContainer {
            id: blocksContainer
            horizontalAlignment: HorizontalAlignment.Center
            verticalAlignment: VerticalAlignment.Center
            animations: [
                FadeTransition {
                    id: blocksContainerFadeAnimation
                    fromOpacity: 0
                    toOpacity: 1
                    duration: 1500
                    easingCurve: StockCurve.CircularIn
                    onEnded: {
                        if ((_settings.value("lostPasswordQuestion", "") == "") || (_settings.value("lostPasswordAnswer", "") == ""))
                            lostPasswordSheet.open()                    
                    }
                }
            ]
        }
    }
}
