/*
 * Copyright (c) 2013-2015 BlackBerry Limited.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import bb.cascades 1.3
import bb.system 1.2
import bb.platform 1.3

Page {
    id: mainPage
    property variant backgroundColor: Color.create("#FFFF933C")
    property variant blockBackgroundColor: Color.create("#FF4B4F5E")
    property variant backgroundSecondColor: Color.Black
    property variant foregroundColor: Color.create("#FFB65D28")
    property variant textColor: Color.create("#FFFF933C")
    property variant secondTextColor: Color.White
//    property variant secondTextColor: Color.create("#FFB65D28")
    
    onCreationCompleted: {
        _app.passwordRequiredChanged.connect(onPasswordRequiredChanged)
    }
    
    function onPasswordRequiredChanged() {
        if (!_settings.value("passwordRequiredNow", false)) {
            successToast.show()
        }
    }
    
    attachedObjects: [
        SystemToast {
            id: successToast
            body: qsTr("Password accepted.") + Retranslate.onLanguageChanged
            button.label: qsTr("OK") + Retranslate.onLanguageChanged
            onFinished: {
                _settings.setValue("passwordRequiredNow", false)
                _app.sendToHL("PASSWORD_SUCCESSFULL")
                _app.quit()
//                Application.quit()
            }
        },
        SystemToast {
            id: wrongPasswordToast
            body: qsTr("Wrong password.") + Retranslate.onLanguageChanged
            button.label: qsTr("OK") + Retranslate.onLanguageChanged
        },
        RenderFence {
            raised: true
            onReached: { passwordTextField.requestFocus() }
        },
        TextStyleDefinition {
            id: headingStyle
            fontSize: FontSize.PointValue
            fontSizeValue: 20
            color: mainPage.textColor
        },
        NotificationDialog { 
            id: notificationDialog
            title: qsTr("Phone protected") + Retranslate.onLanguageChanged
            body: qsTr("You need to enter the password to use this phone") + Retranslate.onLanguageChanged
            buttons: [ SystemUiButton { label: qsTr("Enter password") + Retranslate.onLanguageChanged } ] 
        }
    ]
    
    ScrollView {
        Container {
            background: mainPage.blockBackgroundColor
            leftPadding: ui.du(3)
            rightPadding: leftPadding
            
            layout: DockLayout {}
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            Container {
                horizontalAlignment: HorizontalAlignment.Center
                verticalAlignment: VerticalAlignment.Center
                Label {
                    id: lockScreenMessageLabel
                    text: _settings.value("lockScreenMessage", "")
                    textStyle.base: lockScreenStyle.style
                    content.flags: TextContentFlag.ActiveText | TextContentFlag.Emoticons
                    multiline: true
                    visible: (text != "")
                }
                Label {
                    text: qsTr("Enter password to unlock the phone.") + Retranslate.onLocaleOrLanguageChanged
                    multiline: true
                    textStyle.color: mainPage.secondTextColor
                    horizontalAlignment: HorizontalAlignment.Center
                }
                Container {
                    layout: StackLayout { orientation: LayoutOrientation.LeftToRight }
                    TextField {
                        id: passwordTextField
                        inputMode: TextFieldInputMode.Password
                        horizontalAlignment: HorizontalAlignment.Center
                        onTextChanging: {
                            unlockButton.enabled = (text != "")
                        }
                        input {
                            submitKey: SubmitKey.Done
                            onSubmitted: { unlockButton.clicked() }
                        }
                    }
                    Button {
                        id: unlockButton
                        text: qsTr("Unlock") + Retranslate.onLanguageChanged
                        onClicked: {
                            if (passwordTextField.text == _settings.value("password", "CellNinja")) {
                                successToast.show()
                            }
                            else {
                                wrongPasswordToast.show()
                            }
                            
                            // Update message in case it changed
                            lockScreenMessageLabel.text = _settings.value("lockScreenMessage", "")
                        }
                    }
                }
                Label {
                    visible: ((_settings.value("lostPasswordQuestion", "") != "") && (_settings.value("lostPasswordAnswer", "") != ""))
                    text: qsTr("Lost Password?") + Retranslate.onLanguageChanged
                    textStyle.color: mainPage.secondTextColor
                    textStyle.fontStyle: FontStyle.Italic
                    onTouch: {
                        if (event.isUp()) {
                            lostPasswordPrompt.show()
                        }
                    }
                    attachedObjects: [
                        SystemPrompt {
                            id: lostPasswordPrompt
                            title: qsTr("Lost Password Question") + Retranslate.onLanguageChanged
                            body: _settings.value("lostPasswordQuestion", "")
                            inputField.inputMode: SystemUiInputMode.Password
                            onFinished: {
                                if (inputFieldTextEntry() == _settings.value("lostPasswordAnswer", "")) {
                                    successToast.show()
                                }
                                else {
                                    wrongPasswordToast.show()
                                }
                            }
                        }
                    ]
                }
            }
        }
    }
}
